@@ -43,6 +43,15 @@ ci.transfo <- function(object, tr.choice, level = 0.95, transfo = "linear") {
     lt <- length(tr.choice)
     trs <- tr.choice
     trs.sep <- lapply(trs, strsplit, split = " ")
+    ## Fixing separation of states with names including a space
+    for (i in seq_along(trs.sep)) {
+        if (length(trs.sep[[i]][[1]]) == 2) {
+            next
+        } else {
+            tt <- charmatch(trs.sep[[i]][[1]], object$state.names, nomatch = 0)
+            trs.sep[[i]][[1]] <- object$state.names[tt]
+        }
+    }
     trs.sep <- matrix(unlist(trs.sep), length(trs.sep), 2, byrow = TRUE)
     if (length(transfo) != lt)
         transfo <- rep(transfo[1], lt)
